@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat 
 );
 
-$VERSION = '0.51.07'; # our $VERSION = '';
+$VERSION = '0.51.09'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -184,7 +184,7 @@ sub flattenvariables # IT LISTS THE NUMBER OF VARIABLES PLAY IN A LIST OF BLOCK
 		my @basket = sort { $a <=> $b} uniq(@basket);
 		push ( @flatvarns, \@basket ); ###
 		# IT HAS TO BE CALLED WITH: flatten_variables(@treeseed);
-	} 
+	} # say "\@NUMVARNS!: " . dump(@numvarns);
 }
 
 sub count_variables # IT COUNTS THE FLATTENED VARIABLES
@@ -200,28 +200,28 @@ sub count_variables # IT COUNTS THE FLATTENED VARIABLES
 
 # flatten_variables ( [ [1, 2, 3] , [2, 3, 4] , [3, 4, 5] ], [ [1, 2], [2, 3] ] );
 #count_variables ([1, 2, 3, 4, 5], [1, 2, 3]);
-
+#say "COUNTFLATTENEDVARNS: @countflattenedvarns";
 
 sub fromopt_tosweep # IT CONVERTS A TREE BLOCK SEARCH FORMAT IN THE ORIGINAL OPT'S BLOCKS SEARCH FORMAT.
 {
-	my %thishash = %{ $_[0] }; 
-	my @casegroup = @{ $thishash{casegroup} } ; 
-	my @chancegroup = @{ $thishash{chancegroup} }; 
+	my %thishash = %{ $_[0] }; #say "dump(%thishash): " . dump(%thishash);
+	my @casegroup = @{ $thishash{casegroup} } ; #say "dump(\@casegroup): " . dump(@casegroup);
+	my @chancegroup = @{ $thishash{chancegroup} }; #say "dump(\@chancegroup): " . dump(@chancegroup);
 	my @sweeps;
 	my $countcase = 0;
 	foreach my $case (@casegroup)
 	{
-		my @blockrefs = @$case; 
-		my @chancerefs = @{ $chancegroup[$countcase] }; 
+		my @blockrefs = @$case; #say "dump(\@blocks): " . dump(@blocks);
+		my @chancerefs = @{ $chancegroup[$countcase] }; #say "dump(\@chancerefs): " . dump(@chancerefs);
 		my @sweepblocks;
 		my $countblock = 0;
 		foreach my $elt (@blockrefs)
 		{
-			my @blockelts = @$elt; 
-			my $attachpoint = $blockelts[0]; 
-			my $blocklength = $blockelts[1]; 
-			my @chances = @{ $chancerefs[$countblock] }; 
-			my @sweepblock = @chances[ $attachpoint .. ($attachpoint + $blocklength - 1) ];	
+			my @blockelts = @$elt; #say "dump(\@blockelts): " . dump(@blockelts);
+			my $attachpoint = $blockelts[0]; #say "attachpoint: $attachpoint";
+			my $blocklength = $blockelts[1]; #say "blocklength: $blocklength";
+			my @chances = @{ $chancerefs[$countblock] }; # say "dump(\@chancerefs): " . dump(@chancerefs);
+			my @sweepblock = @chances[ $attachpoint .. ($attachpoint + $blocklength - 1) ];	#say "dump(\@sweepblock): " . dump(@sweepblock);
 			push (@sweepblocks, [@sweepblock]);
 			$countblock++;
 		}
@@ -234,20 +234,20 @@ sub fromopt_tosweep # IT CONVERTS A TREE BLOCK SEARCH FORMAT IN THE ORIGINAL OPT
 
 sub fromopt_tosweep_simple # IT CONVERTS A TREE BLOCK SEARCH FORMAT IN THE ORIGINAL OPT'S BLOCKS SEARCH FORMAT.
 {
-	my %thishash = @_; 
+	my %thishash = @_; #say "dump(%thishash): " . dump(%thishash);
 	my $casegroupref = $thishash{casegroup};
-	my @blocks = @$casegroupref; 
+	my @blocks = @$casegroupref; #say "dump(\@casegroup): " . dump(@casegroup);
 	my $chancegroupref = $thishash{chancegroup};
-	my @chances = @$chancegroupref; 
+	my @chances = @$chancegroupref; #say "dump(\@chancegroup): " . dump(@chancegroup);
 	my $countblock = 0;
 	foreach my $elt (@blocks)
 	{
-		my @blockelts = @$elt; 
-		my $attachpoint = $blockelts[0]; 
-		my $blocklength = $blockelts[1]; 
-		my $chancesref = $chances[$countblock]; 
-		my @chances = @$chancesref; 
-		my @sweepblock = @chances[ $attachpoint .. ($attachpoint + $blocklength - 1) ];	
+		my @blockelts = @$elt; #say "dump(\@blockelts): " . dump(@blockelts);
+		my $attachpoint = $blockelts[0]; #say "attachpoint: $attachpoint";
+		my $blocklength = $blockelts[1]; #say "blocklength: $blocklength";
+		my $chancesref = $chances[$countblock]; # say "dump(\$chancesref): " . dump($chancesref);
+		my @chances = @$chancesref; #say "dump(\@chances): " . dump(@chances);
+		my @sweepblock = @chances[ $attachpoint .. ($attachpoint + $blocklength - 1) ];	#say "dump(\@sweepblock): " . dump(@sweepblock);
 		push (@sweepblocks, [@sweepblock]);
 		$countblock++;
 	}
@@ -283,13 +283,13 @@ sub fromsweep_toopt # IT CONVERTS THE ORIGINAL OPT'S BLOCKS SEARCH FORMAT IN A T
 		my $countblock = 0;
 		foreach(@$_) # BLOCKS
 		{
-			
+			#say "dump(\@\$_): " . dump(@$_);
 			my $swap = $flatvarns[$countcase];
-			my @varns = @$swap; 
+			my @varns = @$swap; #say "dump(\@varns): " . dump(@varns);
 			my @block = @$_;
 			my $blocksize = scalar(@block);
 			my $lc = List::Compare->new(\@varns, \@block);
-			my @intersection = $lc->get_intersection; 
+			my @intersection = $lc->get_intersection; #say "dump(\@intersection): " . dump(@intersection);
 			my @nonbelonging;
 			foreach (@varns)
 			{
@@ -299,8 +299,8 @@ sub fromsweep_toopt # IT CONVERTS THE ORIGINAL OPT'S BLOCKS SEARCH FORMAT IN A T
 					push (@nonbelonging, $_);
 				}
 			}
-			
-			push (@blocks, [@intersection, @nonbelonging] ); 
+			#say "dump(\@nonbelonging): " . dump(@nonbelonging);
+			push (@blocks, [@intersection, @nonbelonging] ); # say "dump(\@blocks): " . dump(@blocks);
 			push (@chances, [0, $blocksize] );
 			$countblock++;
 		}
@@ -318,8 +318,8 @@ sub convcaseseed # IT ADEQUATES THE POINT OF ATTACHMENT OF EACH BLOCK TO THE FAC
 {
 	my $ref = shift;
 	my %hash = %{$ref};
-	my @chanceseed = @{ $hash{ chanceseed } }; 
-	my @caseseed = @{ $hash{ caseseed } }; 
+	my @chanceseed = @{ $hash{ chanceseed } }; #say $tee "IN\@chanceseed:" . dump(@chanceseed);
+	my @caseseed = @{ $hash{ caseseed } }; #say $tee "IN\@caseseed:" . dump(@caseseed);
 	my $countcase = 0;
 	foreach $case (@caseseed)
 	{
@@ -329,8 +329,8 @@ sub convcaseseed # IT ADEQUATES THE POINT OF ATTACHMENT OF EACH BLOCK TO THE FAC
 		my @chancerefs = @$chance;
 		foreach (@blockrefs)
 		{
-			my $chancelt = scalar ( @{ $chancerefs[$countblock] } ); 
-			my $numofelts = ( $chancelt / 3 ); 
+			my $chancelt = scalar ( @{ $chancerefs[$countblock] } ); #say $tee "IN\$chancerefs\[\$countblock]" . dump($chancerefs[$countblock]); say $tee "IN\$chancelt" . dump($chancelt);
+			my $numofelts = ( $chancelt / 3 ); #say $tee "IN\$numofelts" . dump($numofelts);
 			${$_}[0] = ${$_}[0] + $numofelts;
 			$countblock++;
 		}
@@ -346,7 +346,7 @@ sub convchanceseed # IT COUNTS HOW MANY PARAMETERS THERE ARE IN A SEARCH STRUCTU
 	{
 		foreach (@$_)
 		{
-			push (@$_, @$_, @$_); 
+			push (@$_, @$_, @$_); #say "\@\$_ @$_";
 		}
 	} # IT HAS TO BE CALLED WITH convchanceseed(@chanceseed). IT ACTS ON @chanceseed, WHICH IS globsAL.
 	return(@_);
@@ -372,7 +372,7 @@ sub calcoverlaps
 			my @pasttblock = @{$block[ $contblock - 1 ]};
 			my @presentblock = @{$block[ $contblock ]};
 			my $lc = List::Compare->new(\@pasttblock, \@presentblock);
-			my @intersection = $lc->get_intersection; 
+			my @intersection = $lc->get_intersection; #say "dump(\@intersection): " . dump(@intersection);
 			push (@caseoverlaps, [ @intersection ] );
 			$countblock++;
 		}
@@ -391,8 +391,8 @@ sub calcmediumiters
 		my $countblock = 0;
 		foreach ( keys %$_ )
 		{
-			
-			
+			#say "inner dump (\$_): " . dump ($_);
+			#say "dumpalias (\$varinumbers[\$countcase]{\$_}): " . dump ($varinumbers[$countcase]{$_});
 			unless ( defined $mediumiters[$countcase]{$_} )
 			{
 				$mediumiters[$countcase]{$_} = ( ceil( $varinumbers[$countcase]{$_} / 2 ) );
@@ -409,7 +409,7 @@ sub getitersnum
 	my $varinumber = shift;
 	my @varinumbers = @_;
 	my $itersnum = $varinumbers[$countcase]{$varinumber};
-	
+	#say "\$itersnum IN = $itersnum";
 	return $itersnum;
 	# IT HAS TO BE CALLED WITH getitersnum($countcase, $varinumber, @varinumbers);
 }
@@ -421,7 +421,7 @@ sub makefilename # IT DEFINES A FILE NAME GIVEN A %carrier.
 	my $countcase = 0;
 	foreach $key (sort {$a <=> $b} (keys %carrier) )
 	{
-		$filename = $filename . $key . "-" . $carrier{$key} . "_"; 
+		$filename = $filename . $key . "-" . $carrier{$key} . "_"; #say "filename: $filename";
 	} 
 	return ($filename); # IT HAS TO BE CALLED WITH: makefilename(%carrier);
 }
@@ -458,37 +458,37 @@ sub getrootname
 
 sub extractcase # IT EXTRACTS THE ITEMS TO BE CHANCED FROM A  %carrier, UPDATES THE FILE NAME AND CREATES THE NEW ITEM'S CARRIER
 {
-	my $file = shift; 
-	my $carrierref = shift; 
-	my @carrierarray = %$carrierref; 
-	my %carrier = %$carrierref;  
-	my $num = ( scalar(@carrierarray) / 2 ); 
+	my $file = shift; #say "file: $file";
+	my $carrierref = shift; #say "\$carrierref: " . dump($carrierref);
+	my @carrierarray = %$carrierref; #say "\@carrierarray: " .  dump(@carrierarray);
+	my %carrier = %$carrierref;  #say "\%carrier: " . dump(%carrier);
+	my $num = ( scalar(@carrierarray) / 2 ); #say "\$num: $num";
 	my $transfile = $file;
 	$transfile = "_" . "$transfile";
 	my $counter = 0;
 	my %provhash;
 	while ($counter < $num)
-	{	
-		$transfile =~ /_(\d+)-(\d+)_/; 
+	{	#say "\$counter: $counter";
+		$transfile =~ /_(\d+)-(\d+)_/; #say "\$1: $1, \$2: $2"; #say "\$transfileBEFORE: $transfile";
 		if ( ($1) and ($2) )
 		{
 			$provhash{$1} = "$2"; 
 		}
-		$transfile =~ s/$1-$2//; 
+		$transfile =~ s/$1-$2//; #say "\$transfileAFTER: $transfile";
 		$counter++;
-	} 
+	} #say "provhash: " . dump(%provhash);
 	foreach my $key (keys %provhash)
 	{
-		$carrier{$key} = $provhash{$key}; 
+		$carrier{$key} = $provhash{$key}; #say "carrier: " . dump(%carrier);
 	}
-	my $to = makefilename(%carrier); 
+	my $to = makefilename(%carrier); # say "\$to: $to"; say "carrier: " . dump(%carrier);
 	return($to, \%carrier); # IT HAS TO BE CALLED WITH: extractcase("$string", \%carrier), WHERE STRING IS A PIECE OF FILENAME WITH PARAMETERS.
 }
 
 sub definerootcases #### DEFINES THE ROOT-CASE'S NAME.
 {
-	my @sweeps = @{ $_[0] }; 
-	my @miditers = @{ $_[1] }; 
+	my @sweeps = @{ $_[0] }; #say "dump( \@sweeps) PRE: " . dump(@sweeps); 
+	my @miditers = @{ $_[1] }; #say "dump( \@miditers) PRE: " . dump(@miditers); 
 	my @rootnames;
 	my $countcase = 0;
 	foreach my $sweep (@sweeps)
@@ -638,16 +638,16 @@ sub flattenbox
 
 sub integratebox
 {
-	my @arrelts = @{ $_[0] }; 
-	my %carrier = %{ $_[1] }; 
-	my $file = $_[2]; 
+	my @arrelts = @{ $_[0] }; #say "\@arrelts " . dump(@arrelts);
+	my %carrier = %{ $_[1] }; #say "\%carrier " . dump(%carrier);
+	my $file = $_[2]; #say "\$file " . dump($file);
 	my @newbox;
 	foreach my $eltref ( @arrelts )
 	{
-		my @elts = @{ $eltref }; 
-		my $target = $elts[0]; 
-		my $origin = $elts[3]; 
-		my @result = extractcase( $target, \%carrier ); 
+		my @elts = @{ $eltref }; #say "\@elts " . dump(@elts);
+		my $target = $elts[0]; #say "\$target " . dump($target);
+		my $origin = $elts[3]; #say "\$origin " . dump($origin);
+		my @result = extractcase( $target, \%carrier ); #say "\@result: " . dump(@result);
 		my $righttarget = $result[0];
 		my @result = extractcase( $origin, \%carrier );
 		my $rightorigin = $result[0];
@@ -691,22 +691,22 @@ sub callcase # IT PROCESSES THE CASES.
 {
 	my $swap = shift;
 	my %dat = %{$swap};
-	my $countcase = $dat{countcase}; 
-	my $countblock = $dat{countblock}; 
-	my @miditers = @{ $dat{miditers} }; 
-	my @winneritems = @{ $dat{winneritems} }; 
-	my %dirfiles = %{ $dat{dirfiles} }; 
-	my @uplift = @{ $dat{uplift} }; 
+	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase);
+	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock);
+	my @miditers = @{ $dat{miditers} }; #say "dump(\@miditers): " . dump(@miditers); # IT BECOMES THE CARRIER. INITIALIZED AT FIRST BLOCKS; INHERITED AFTER.
+	my @winneritems = @{ $dat{winneritems} }; #say "dumpIN( \@winneritems) " . dump(@winneritems);
+	my %dirfiles = %{ $dat{dirfiles} }; #say "dumpIN( \%dirfiles) " . dump(%dirfiles);
+	my @uplift = @{ $dat{uplift} }; #say "dumpIN( \@uplift) " . dump(@uplift);
 	#eval($getparshere);
 	
-	my $rootname = getrootname(\@rootnames, $countcase); 
-	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); 
-	my @blocks = getblocks(\@sweeps, $countcase);  
-	my $toitem = getitem(\@winneritems, $countcase, $countblock); 
-	my $from = getline($toitem); 
+	my $rootname = getrootname(\@rootnames, $countcase); #say "dump(\$rootname): " . dump($rootname);
+	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); #say "dumpIN( \@blockelts) " . dump(@blockelts);
+	my @blocks = getblocks(\@sweeps, $countcase);  #say "dumpIN( \@blocks) " . dump(@blocks);
+	my $toitem = getitem(\@winneritems, $countcase, $countblock); #say "dump(\$toitem): " . dump($toitem);
+	my $from = getline($toitem); #say "dump(\$from): " . dump($from);
 	#my @winnerlines = getlines( \@winneritems ); say "dump(\@winnerlines): " . dump(@winnerlines);
-	my %varnums = getcase(\@varinumbers, $countcase); 
-	my %mids = getcase(\@miditers, $countcase); 
+	my %varnums = getcase(\@varinumbers, $countcase); #say "dumpININ---(\%varnums): " . dump(%varnums); 
+	my %mids = getcase(\@miditers, $countcase); #say "dumpININ---(\%mids): " . dump(%mids); 
 	#eval($getfly);
 	
 	if ($countblock == 0 ) { my %dirfiles; }
@@ -733,19 +733,19 @@ sub callcase # IT PROCESSES THE CASES.
 	
 	#if ( ($countcase > 0) or ($countblock > 0) )
 	#{
-		
+		#say $tee "#Called for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	#}
 
-	#my @taken = extractcase("$toitem", \%mids); 
-	#my $to = $taken[0]; 
-	#my %carrier = %{$taken[1]}; 
-	
+	#my @taken = extractcase("$toitem", \%mids); #say "------->taken: " . dump(@taken);
+	#my $to = $taken[0]; #say "to-------->: $to";
+	#my %carrier = %{$taken[1]}; #say "\%instancecarrier:--------->" . dump(%instancecarrier);
+	#say $tee "#Calling a new block for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $casedata = { 
 				countcase => $countcase, countblock => $countblock,
 				miditers => \@miditers,  winneritems => \@winneritems, 
 				dirfiles => \%dirfiles, uplift => \@uplift
 			};
-	
+	#say $tee "IN OPT.pm, \$casedata: " . dump($casedata); 
 	callblocks( $casedata );
 	if ( $countblock != 0 ) { return($casedata); }
 }
@@ -754,31 +754,31 @@ sub callblocks # IT CALLS THE SEARCH ON BLOCKS.
 {	
 	my $swap = shift;
 	my %dat = %{$swap};
-	my $countcase = $dat{countcase}; 
-	my $countblock = $dat{countblock}; 
-	my @miditers = @{ $dat{miditers} }; 
-	my @winneritems = @{ $dat{winneritems} }; 
-	my %dirfiles = %{ $dat{dirfiles} }; 
-	my @uplift = @{ $dat{uplift} }; 
+	my $countcase = $dat{countcase}; #say $tee "dump(\$countcase): " . dump($countcase);
+	my $countblock = $dat{countblock}; #say $tee "dump(\$countblock): " . dump($countblock);
+	my @miditers = @{ $dat{miditers} }; #say $tee "dump(\@miditers): " . dump(@miditers);
+	my @winneritems = @{ $dat{winneritems} }; #say $tee "dumpIN( \@winneritems) " . dump(@winneritems);
+	my %dirfiles = %{ $dat{dirfiles} }; #say $tee "dumpIN( \%dirfiles) " . dump(%dirfiles);
+	my @uplift = @{ $dat{uplift} }; #say $tee "dumpIN( \@uplift) " . dump(@uplift);
 	#eval($getparshere);
 	
-	my $rootname = getrootname(\@rootnames, $countcase); 
-	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); 
-	my @blocks = getblocks(\@sweeps, $countcase);  
-	my $toitem = getitem(\@winneritems, $countcase, $countblock); 
-	my $from = getline($toitem); 
-	my %varnums = getcase(\@varinumbers, $countcase); 
-	my %mids = getcase(\@miditers, $countcase); 
+	my $rootname = getrootname(\@rootnames, $countcase); #say $tee "dump(\$rootname): " . dump($rootname);
+	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); #say $tee "dumpIN( \@blockelts) " . dump(@blockelts);
+	my @blocks = getblocks(\@sweeps, $countcase);  #say $tee "dumpIN( \@blocks) " . dump(@blocks);
+	my $toitem = getitem(\@winneritems, $countcase, $countblock); #say $tee "dump(\$toitem): " . dump($toitem);
+	my $from = getline($toitem); #say $tee "dump(\$from): " . dump($from);
+	my %varnums = getcase(\@varinumbers, $countcase); #say $tee "dumpININ---(\%varnums): " . dump(%varnums); 
+	my %mids = getcase(\@miditers, $countcase); #say $tee "dumpININ---(\%mids): " . dump(%mids); 
 	#eval($getfly);
-	
-	
+	#say $tee "#Called for a new block for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Calling to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $blockdata = 
 	{ 
 		countcase => $countcase, countblock => $countblock,
 		miditers => \@miditers,  winneritems => \@winneritems, 
 		dirfiles => \%dirfiles, uplift => \@uplift, 
 	}; 
-	
+	#say $tee "\ndumpBLOCK(\$blockdata): " . dump($blockdata) . "\n\n";
 	deffiles( $blockdata );
 }
 	
@@ -786,56 +786,56 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 {
 	my $swap = shift;
 	my %dat = %{$swap};
-	my $countcase = $dat{countcase}; 
-	my $countblock = $dat{countblock}; 
-	my @miditers = @{ $dat{miditers} }; 
-	my @winneritems = @{ $dat{winneritems} }; 
-	my %dirfiles = %{ $dat{dirfiles} }; 
-	my @uplift = @{ $dat{uplift} }; 
+	my $countcase = $dat{countcase}; #say $tee  "#dump(\$countcase): " . dump($countcase);
+	my $countblock = $dat{countblock}; #say $tee  "#dump(\$countblock): " . dump($countblock);
+	my @miditers = @{ $dat{miditers} }; #say $tee  "#dump(\@miditers): " . dump(@miditers);
+	my @winneritems = @{ $dat{winneritems} }; #say $tee  "#dumpIN( \@winneritems) " . dump(@winneritems);
+	my %dirfiles = %{ $dat{dirfiles} }; #say $tee  "#dumpIN( \%dirfiles) " . dump(%dirfiles);
+	my @uplift = @{ $dat{uplift} }; #say $tee  "#dumpIN( \@uplift) " . dump(@uplift);
 	#eval($getparshere);
 	
-	my $rootname = getrootname(\@rootnames, $countcase); 
-	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); 
-	my @blocks = getblocks(\@sweeps, $countcase);  
-	my $toitem = getitem(\@winneritems, $countcase, $countblock); 
-	my $from = getline($toitem); 
-	my %varnums = getcase(\@varinumbers, $countcase); 
-	my %mids = getcase(\@miditers, $countcase); 
+	my $rootname = getrootname(\@rootnames, $countcase); #say $tee  "#dump(\$rootname): " . dump($rootname);
+	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); #say $tee "#dumpIN( \@blockelts) " . dump(@blockelts);
+	my @blocks = getblocks(\@sweeps, $countcase);  #say $tee "#dumpIN( \@blocks) " . dump(@blocks);
+	my $toitem = getitem(\@winneritems, $countcase, $countblock); #say $tee  "#dump(\$toitem): " . dump($toitem);
+	my $from = getline($toitem); #say $tee  "#dump(\$from): " . dump($from);
+	my %varnums = getcase(\@varinumbers, $countcase); #say $tee  "#dumpININ---(\%varnums): " . dump(%varnums); 
+	my %mids = getcase(\@miditers, $countcase); #say $tee  "#dumpININ---(\%mids): " . dump(%mids);
 	#eval($getfly);
 	
+	#say $tee "#Called to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
-	
-	my $rootitem = "$file" . "_"; 
+	my $rootitem = "$file" . "_"; #say "\$rootitem $rootitem";
 	my (@basket, @box);
 	push (@basket, [ $rootitem ] );
 	foreach my $var ( @blockelts )
 	{
 		my @bucket;
-		my $maxvalue = $varnums{$var}; 
+		my $maxvalue = $varnums{$var}; #say $tee  "#\$countblock $countblock, var: $var, maxvalue: $maxvalue";
 		foreach my $elt (@basket)
 		{
-			my $root = $elt->[0]; 
+			my $root = $elt->[0]; #say $tee  "#\$root " . dump($root);
 			my $cnstep = 1;
 			while ( $cnstep <= $maxvalue)
 			{
 				my $olditem = $root;
-				my $item = "$root" . "$var" . "-" . "$cnstep" . "_" ; 
-				push (@bucket, [$item, $var, $cnstep, $olditem] ); 
+				my $item = "$root" . "$var" . "-" . "$cnstep" . "_" ; #say $tee  "#\$item making: $item, \$root: $root, \$var: $var, \$cnstep: $cnstep, \$root: $root ";
+				push (@bucket, [$item, $var, $cnstep, $olditem] ); #say $tee  "#\@bucketIN " . dump(@bucket);
 				$cnstep++;
 			}
 		} 
 		@basket = ();
 		@basket = @bucket;
 		push ( @box, [ @bucket ] );
-		
+		#say $tee  "#\@box INOUT" . dump(@box);
 	} 
+	#say $tee  "#\@box!: " . dump ( @box );
 	
+	my @flattened = flattenbox(@box); #say $tee  "#\@flattened: " . dump(@flattened) . ", " . scalar(@flattened);
+	my @integrated = integratebox(\@flattened, \%mids, $file); #say $tee  "#\@integrated " . dump(@integrated) . ", " . scalar(@integrated);
+	my @finalbox = filterbox(@integrated); #say $tee  "#\@finalbox " . dump(@finalbox) . ", " . scalar(@finalbox); 
 	
-	my @flattened = flattenbox(@box); 
-	my @integrated = integratebox(\@flattened, \%mids, $file); 
-	my @finalbox = filterbox(@integrated); 
-	
-	
+	#say $tee "#Calling to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $datatowork = 
 	{ 
 		countcase => $countcase, countblock => $countblock,
@@ -843,7 +843,7 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 		dirfiles => \%dirfiles, uplift => \@uplift, 
 		basket => \@finalbox   
 	} ;
-	
+	#say $tee "\ndumper-datatowork: " . dump($datatowork) . "\n\n";
 	setlaunch( $datatowork );
 }	
 
@@ -851,49 +851,49 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 {
 	my $swap = shift;
 	my %dat = %{$swap};
-	my $countcase = $dat{countcase}; 
-	my $countblock = $dat{countblock}; 
-	my @miditers = @{ $dat{miditers} }; 
-	my @winneritems = @{ $dat{winneritems} }; 
-	my %dirfiles = %{ $dat{dirfiles} }; 
-	my @uplift = @{ $dat{uplift} }; 
-	my @basket = @{ $dat{basket} }; 
+	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase);
+	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock);
+	my @miditers = @{ $dat{miditers} }; #say "dump(\@miditers): " . dump(@miditers);
+	my @winneritems = @{ $dat{winneritems} }; #say "dumpIN( \@winneritems) " . dump(@winneritems);
+	my %dirfiles = %{ $dat{dirfiles} }; #say "dumpIN( \%dirfiles) " . dump(%dirfiles);
+	my @uplift = @{ $dat{uplift} }; #say "dumpIN( \@uplift) " . dump(@uplift);
+	my @basket = @{ $dat{basket} }; #say "dumpIN( \@basket) " . dump(@basket);
 	#eval($getparshere);
 			
-	my $rootname = getrootname(\@rootnames, $countcase); 
-	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); 
-	my @blocks = getblocks(\@sweeps, $countcase);  
-	my $toitem = getitem(\@winneritems, $countcase, $countblock); 
-	my $from = getline($toitem); 
-	my %varnums = getcase(\@varinumbers, $countcase); 
-	my %mids = getcase(\@miditers, $countcase); 
+	my $rootname = getrootname(\@rootnames, $countcase); #say "dump(\$rootname): " . dump($rootname);
+	my @blockelts = getblockelts(\@sweeps, $countcase, $countblock); #say "dumpIN( \@blockelts) " . dump(@blockelts);
+	my @blocks = getblocks(\@sweeps, $countcase);  #say "dumpIN( \@blocks) " . dump(@blocks);
+	my $toitem = getitem(\@winneritems, $countcase, $countblock); #say "dump(\$toitem): " . dump($toitem);
+	my $from = getline($toitem); #say "dump(\$from): " . dump($from);
+	my %varnums = getcase(\@varinumbers, $countcase); #say "dumpININ---(\%varnums): " . dump(%varnums); 
+	my %mids = getcase(\@miditers, $countcase); #say "dumpININ---(\%mids): " . dump(%mids); 
 	#eval($getfly);
 	
-	
+	#say $tee "#Called to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
 	my ( @instances, %carrier);
 	#if ($countblock == 0)
 	#{
-	#	%carrier = %mids; 
+	#	%carrier = %mids; #say "\%carrier! STARTING:--->" . dump(%carrier);
 	#}
 	#else 
 	#{
 	#	my $prov = "_" . "$winnerline";
-	#	%carrier = extractcase( $prov , \%carrier ); 
+	#	%carrier = extractcase( $prov , \%carrier ); #say "\%carrier! EXTRACTED:--->" . dump(%carrier);
 	#}
 
 	foreach my $elt ( @basket )
 	{
 		
-		my $newpars = $$elt[0]; 
-		my $countvar = $$elt[1]; 
-		my $countstep = $$elt[2]; 
-		my $oldpars = $$elt[3]; 
-		my @taken = extractcase("$newpars", \%mids); 
-		my $to = $taken[0]; 
-		#my %instancecarrier = %{$taken[1]}; 
-		my @olds = extractcase("$oldpars", \%mids); 
-		my $origin = $olds[0]; 
+		my $newpars = $$elt[0]; #say "\$newpars : $newpars"; 
+		my $countvar = $$elt[1]; #say "\$countvar : $countvar"; 
+		my $countstep = $$elt[2]; #say "\$countstep : $countstep"; 
+		my $oldpars = $$elt[3]; #say "\$oldpars : $oldpars"; 
+		my @taken = extractcase("$newpars", \%mids); #say "--->taken: " . dump(@taken);
+		my $to = $taken[0]; #say "to--->: $to";
+		#my %instancecarrier = %{$taken[1]}; #say "\%instancecarrier!:--->" . dump(%instancecarrier); # UNUSED
+		my @olds = extractcase("$oldpars", \%mids); #say "--->@olds " . dump(@olds);
+		my $origin = $olds[0]; #say "$origin--->: $origin";
 		push (@instances, 
 		{ 
 			countcase => $countcase, countblock => $countblock,
@@ -903,9 +903,9 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 			origin => $origin
 		} );
 	} 
+	#say $tee "#Calling to execute the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
-	
-	
+	#say $tee "\ninstances: " . dump(@instances). "\n\n"; ### ZZZ
 	exe( @instances ); # IT HAS TO BE CALLED WITH: setlaunch(@datatowork). @datatowork ARE CONSTITUTED BY AN ARRAY OF: ( [ \@blocks, \%varnums, \%bases, $name, $countcase, \@blockelts, $countblock ], ... )
 }	
 		
@@ -915,17 +915,17 @@ sub exe
 	
 	my $firstinst = $instances[0];
 	my %d = %{ $firstinst };
-	my $countcase = $d{countcase}; 
-	my $countblock = $d{countblock}; 
+	my $countcase = $d{countcase}; #say "dump(\$countcase): " . dump($countcase);
+	my $countblock = $d{countblock}; #say "dump(\$countblock): " . dump($countblock);
 	my %dirfiles = %{ $d{ dirfiles } };
 	
 	say $tee "#Executing new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-	
+	#say $tee "Do what:" . dump(%dowhat);
 	
 	if ( $dowhat{morph} eq "y" ) 
 	{ 
 		say $tee "#Calling morphing operations for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-		
+		#say $tee "WITH: \@instances " . dump(@instances) . ", \$countcase $countcase, \$countblock $countblock, \%dirfiles " . dump(%dirfiles) . ".";
 		my @result = Sim::OPT::Morph::morph( 
 		{ 
 			configfile => $configfile, instances => \@instances, countcase => $countcase, countblock => $countblock,
@@ -943,7 +943,7 @@ sub exe
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
 			dirfiles => \%dirfiles
 		} );
-		$dirfiles{simcases} = $result[0]; 
+		$dirfiles{simcases} = $result[0]; #say $tee "\$dirfiles{simcases} : " . dump( $dirfiles{simcases} );
 		$dirfiles{simstruct} = $result[1]; 
 	}
 
@@ -955,7 +955,7 @@ sub exe
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
 			dirfiles => \%dirfiles
 		} );
-		$dirfiles{retcases} = $result[0]; 
+		$dirfiles{retcases} = $result[0]; #say $tee "\$dirfiles{retcases} : " . dump( $dirfiles{retcases} );
 		$dirfiles{retstruct} = $result[1];
 		$dirfiles{notecases} = $result[2];
 	}
@@ -972,7 +972,6 @@ sub exe
 		$dirfiles{repstruct} = $result[1];
 		$dirfiles{mergestruct} = $result[2];
 		$dirfiles{mergecases} = $result[3];
-		$repfile = $result[4];
 	}
 
 	if ( $dowhat{descend} eq "y" )
@@ -1012,18 +1011,18 @@ sub exe
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
 			dirfiles => \%dirfiles
 		} );
-	} 
+	} #say "getexe: " . dump(@instances);
 } # END SUB exe
 	
 sub start
 {
 ###########################################
-print "THIS IS Sim::OPT (version 0.47.16),
+say "\nTHIS IS Sim::OPT (version 0.47.16),
 a morphing and optimizazion program.
 
 .  .  .  .  .  .  .  .  .  .  .  .  .
 
-Please insert the name of a configuration file for OPT (Unix path)\n\n";
+Please insert the name of a configuration file for OPT (Unix path)\n";
 ###########################################
 	$configfile = <STDIN>;
 	chomp $configfile;
@@ -1085,18 +1084,18 @@ sub opt
 	{
 		if ( ( @sweepseed ) and ( @chancedata ) ) # IF THIS VALUE IS DEFINED. TO BE FIXED. ZZZ
 		{
-			my $yield = fromsweep_toopt( @sweeps ); 
-			@caseseed = @{ $yield[0] }; 
-			@chanceseed = @{ $yield[1] }; 
+			my $yield = fromsweep_toopt( @sweeps ); #say $tee "Dumper(\$yield): " . Dumper($yield);
+			@caseseed = @{ $yield[0] }; #say $tee "Dumper(\@caseseed): " . Dumper(@caseseed);
+			@chanceseed = @{ $yield[1] }; #say $tee "Dumper(\@chanceseed): " . Dumper(@chanceseed);
 		}
 	}
 			
-	
-	
-	@chanceseed = convchanceseed(@chanceseed); 
-	@caseseed = convcaseseed( { caseseed => \@caseseed, chanceseed => \@chanceseed } ); 
-	
-	
+	#say $tee "\@chanceseedINI: " . Dumper(@chanceseed); # GLOBAL ZZZ
+	#say $tee "\@caseseedINI: " . Dumper(@caseseed); # GLOBAL ZZZ
+	@chanceseed = convchanceseed(@chanceseed); #say $tee "convchanceseed Dumper(\@chanceseed): " . Dumper(@chanceseed); # GLOBAL ZZZ	
+	@caseseed = convcaseseed( { caseseed => \@caseseed, chanceseed => \@chanceseed } ); #say $tee "convcaseseed Dumper(\@caseseed): " . Dumper(@caseseed) ; # GLOBAL ZZZ
+	#say $tee "Dumper(\@chancedata): " . Dumper(@chancedata) ; # GLOBAL ZZZ
+	#say $tee "Dumper(\$dimchance): " . Dumper($dimchance) ; # GLOBAL ZZZ
 	my (@sweeps_);
 	
 	if ( ( $target eq "takechance" ) and (@chancedata) and ( $dimchance ) ) 
@@ -1114,25 +1113,25 @@ sub opt
 		
 		if ( not (@sweeps) ) # CONSERVATIVE CONDITION. IT MAY BE CHANCED. ZZZ
 		{
-			@sweeps = @sweeps_ ; 
+			@sweeps = @sweeps_ ; # say "\@tree: " . Dumper(@tree);
 		}
 	}		
 	elsif ( $target eq "opt" )
 	{
 		#my  $itersnum = $varinumbers[$countcase]{$varinumber}; say "\$itersnum: $itersnum"; 
-		
+		#say "dump(\@varinumbers), " . dump(@varinumbers); #say "dumpBEFORE(\@miditers), " . dump(@miditers);
 	
 		calcoverlaps( @sweeps ); # PRODUCES @calcoverlaps WHICH IS global. ZZZ
+		#say $tee "VARINUMBERS: " . dump ( @varinumbers );
+		@mediumiters = calcmediumiters( @varinumbers ); #say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
+		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); #say "\$itersnum OUT = $itersnum";
 		
-		@mediumiters = calcmediumiters( @varinumbers ); 
-		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); 
-		
-		@rootnames = definerootcases(\@sweeps, \@mediumiters); 
+		@rootnames = definerootcases(\@sweeps, \@mediumiters); #say $tee "BEGINNING \@rootnames " . dump(@rootnames); 
 		
 		my $countcase = 0;
 		my $countblock = 0;
 
-		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); 
+		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); #say $tee "BEGINNING \@winneritems " . dump(@winneritems);
 		
 		callcase( { countcase => $countcase, rootnames => \@rootnames, countblock => $countblock, 
 		miditers => \@mediumiters,  winneritems => \@winneritems } );
